@@ -8,21 +8,14 @@ import inspect
 import os
 import socket
 import sys
-from _frozen_importlib_external import _NamespacePath
 from contextlib import contextmanager
-from urllib.parse import quote
-from urllib.parse import SplitResult
-from urllib.parse import unquote
 from urllib.parse import urljoin  # noqa: F401
-from urllib.parse import urlparse
-from urllib.parse import urlsplit
-from urllib.parse import urlunsplit
+from urllib.parse import SplitResult, quote, unquote, urlparse, urlsplit, urlunsplit
 from urllib.request import pathname2url  # noqa: F401
 
+from _frozen_importlib_external import _NamespacePath
 from packaging.version import Version
-from tornado.httpclient import AsyncHTTPClient
-from tornado.httpclient import HTTPClient
-from tornado.httpclient import HTTPRequest
+from tornado.httpclient import AsyncHTTPClient, HTTPClient, HTTPRequest
 from tornado.netutil import Resolver
 
 
@@ -217,6 +210,7 @@ def run_sync(maybe_async):
         # that was not something async, just return it
         return maybe_async
     # it is async, we need to run it in an event loop
+
     def wrapped():
         create_new_event_loop = False
         try:
@@ -288,7 +282,7 @@ def unix_socket_in_use(socket_path):
     try:
         sock = socket.socket(socket.AF_UNIX, socket.SOCK_STREAM)
         sock.connect(socket_path)
-    except socket.error:
+    except OSError:
         return False
     else:
         return True
@@ -352,7 +346,9 @@ def fetch(urlstring, method="GET", body=None, headers=None):
     Send a HTTP, HTTPS, or HTTP+UNIX request
     to a Tornado Web Server. Returns a tornado HTTPResponse.
     """
-    with _request_for_tornado_client(urlstring) as request:
+    with _request_for_tornado_client(
+        urlstring, method=method, body=body, headers=headers
+    ) as request:
         response = HTTPClient(AsyncHTTPClient).fetch(request)
     return response
 
@@ -362,7 +358,9 @@ async def async_fetch(urlstring, method="GET", body=None, headers=None, io_loop=
     Send an asynchronous HTTP, HTTPS, or HTTP+UNIX request
     to a Tornado Web Server. Returns a tornado HTTPResponse.
     """
-    with _request_for_tornado_client(urlstring) as request:
+    with _request_for_tornado_client(
+        urlstring, method=method, body=body, headers=headers
+    ) as request:
         response = await AsyncHTTPClient(io_loop).fetch(request)
     return response
 
@@ -431,7 +429,7 @@ def filefind(filename, path_dirs=None):
         if os.path.isfile(testname):
             return os.path.abspath(testname)
 
-    raise IOError("File %r does not exist in any of the search paths: %r" % (filename, path_dirs))
+    raise OSError(f"File {filename!r} does not exist in any of the search paths: {path_dirs!r}")
 
 
 def expand_path(s):
