@@ -2,22 +2,23 @@ import os
 import sys
 import time
 from itertools import combinations
-from typing import Dict
-from typing import Optional
-from typing import Tuple
+from typing import Dict, Optional, Tuple
 from unittest.mock import patch
 
 import pytest
-from nbformat import v4 as nbformat
 from nbformat import ValidationError
+from nbformat import v4 as nbformat
 from tornado.web import HTTPError
 from traitlets import TraitError
 
-from ...utils import expected_http_error
-from jupyter_server.services.contents.filemanager import AsyncFileContentsManager
-from jupyter_server.services.contents.filemanager import FileContentsManager
+from jupyter_server.services.contents.filemanager import (
+    AsyncFileContentsManager,
+    FileContentsManager,
+)
 from jupyter_server.utils import ensure_async
 
+from ...utils import expected_http_error
+
 
 @pytest.fixture(
     params=[
@@ -190,7 +191,7 @@ async def test_bad_symlink(jp_file_contents_manager_class, tmp_path):
     file_model = await ensure_async(cm.new_untitled(path=path, ext=".txt"))
 
     # create a broken symlink
-    symlink(cm, "target", "%s/%s" % (path, "bad symlink"))
+    symlink(cm, "target", "{}/{}".format(path, "bad symlink"))
     model = await ensure_async(cm.get(path))
 
     contents = {content["name"]: content for content in model["content"]}
@@ -210,7 +211,7 @@ async def test_recursive_symlink(jp_file_contents_manager_class, tmp_path):
     file_model = await ensure_async(cm.new_untitled(path=path, ext=".txt"))
 
     # create recursive symlink
-    symlink(cm, "%s/%s" % (path, "recursive"), "%s/%s" % (path, "recursive"))
+    symlink(cm, "{}/{}".format(path, "recursive"), "{}/{}".format(path, "recursive"))
     model = await ensure_async(cm.get(path))
 
     contents = {content["name"]: content for content in model["content"]}
@@ -225,7 +226,7 @@ async def test_good_symlink(jp_file_contents_manager_class, tmp_path):
     cm = jp_file_contents_manager_class(root_dir=td)
     parent = "test good symlink"
     name = "good symlink"
-    path = "{0}/{1}".format(parent, name)
+    path = f"{parent}/{name}"
     _make_dir(cm, parent)
 
     file_model = await ensure_async(cm.new(path=parent + "/zfoo.txt"))
@@ -394,7 +395,7 @@ async def test_get(jp_contents_manager):
     assert "path" in model2
     assert "content" in model2
     assert model2["name"] == "Untitled.ipynb"
-    assert model2["path"] == "{0}/{1}".format(sub_dir.strip("/"), name)
+    assert model2["path"] == "{}/{}".format(sub_dir.strip("/"), name)
 
     # Test with a regular file.
     file_model_path = (await ensure_async(cm.new_untitled(path=sub_dir, ext=".txt")))["path"]
@@ -442,7 +443,7 @@ async def test_get(jp_contents_manager):
         elif entry["path"] == file_model_no_content["path"]:
             assert entry == file_model_no_content
         else:
-            assert False, "Unexpected directory entry: %s" % entry()
+            raise AssertionError("Unexpected directory entry: %s" % entry())
 
     with pytest.raises(HTTPError):
         await ensure_async(cm.get("foo", type="file"))
@@ -579,7 +580,7 @@ async def test_delete_non_empty_folder(delete_to_trash, always_delete, error, jp
             await ensure_async(cm.delete_file(dir))
     else:
         await ensure_async(cm.delete_file(dir))
-        assert await ensure_async(cm.dir_exists(dir)) == False
+        assert await ensure_async(cm.dir_exists(dir)) is False
 
 
 async def test_rename(jp_contents_manager):
@@ -645,7 +646,7 @@ async def test_copy(jp_contents_manager):
     cm = jp_contents_manager
     parent = "å b"
     name = "nb √.ipynb"
-    path = "{0}/{1}".format(parent, name)
+    path = f"{parent}/{name}"
     _make_dir(cm, parent)
 
     orig = await ensure_async(cm.new(path=path))
@@ -657,11 +658,20 @@ async def test_copy(jp_contents_manager):
     copy2 = await ensure_async(cm.copy(path, "å b/copy 2.ipynb"))
     assert copy2["name"] == "copy 2.ipynb"
     assert copy2["path"] == "å b/copy 2.ipynb"
+
     # copy with specified path
     copy2 = await ensure_async(cm.copy(path, "/"))
     assert copy2["name"] == name
     assert copy2["path"] == name
 
+    # copy to destination whose parent dir does not exist
+    with pytest.raises(HTTPError) as e:
+        await ensure_async(cm.copy(path, "å x/copy 2.ipynb"))
+
+    copy3 = await ensure_async(cm.copy(path, "/copy 3.ipynb"))
+    assert copy3["name"] == "copy 3.ipynb"
+    assert copy3["path"] == "copy 3.ipynb"
+
 
 async def test_mark_trusted_cells(jp_contents_manager):
     cm = jp_contents_manager
