@@ -8,14 +8,14 @@ from unittest.mock import patch
 
 import pytest
 import tornado
-from tornado.httpclient import HTTPRequest
-from tornado.httpclient import HTTPResponse
+from tornado.httpclient import HTTPRequest, HTTPResponse
 from tornado.web import HTTPError
 
-from .utils import expected_http_error
 from jupyter_server.gateway.managers import GatewayClient
 from jupyter_server.utils import ensure_async
 
+from .utils import expected_http_error
+
 
 def generate_kernelspec(name):
     argv_stanza = ["python", "-m", "ipykernel_launcher", "-f", "{connection_file}"]
@@ -44,7 +44,7 @@ kernelspecs = {
 
 
 # maintain a dictionary of expected running kernels.  Key = kernel_id, Value = model.
-running_kernels = dict()
+running_kernels = {}
 
 
 def generate_model(name):
